@@ -4,7 +4,7 @@
 import ftputil
 import utils.dir as directory
 # import utils.file as file
-from utils import file
+import utils.file as file
 
 
 def ftp_connect(address, user_name=None, password=None):
